%define __python %{__python3}

Name:		blender
Version:	2.78c
Release:	%mkrel 4
Summary:	A fully functional 3D modeling/rendering/animation package
License:	GPLv2+
Group:		Graphics/3D
URL:		http://www.blender.org/
Source0:	http://download.blender.org/source/%{name}-%{version}.tar.gz
Patch0:		blender-2.76-localedir.patch
Patch1:		blender-2.60-error-when-missing-sse.patch
Patch2:		blender-2.58-static-lib.patch
Patch3:		blender-2.65-openjpeg_stdbool.patch
# Patch submitted upstream - Blender Patches item #19234,
Patch4:		blender-2.67a-uninit-var.patch
Patch5:		blender-2.78b-sse2.patch
Patch6:		blender-2.78b-link.patch
# Fix build against eigen3-3.3.x
Patch7:		blender-2.78a-upstream-jet.h.patch
Patch8:		blender-2.78a-add-blenderplayer-manpage.patch

BuildRequires:	cmake >= 2.8
BuildRequires:	git-core
BuildRequires:	boost-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	libgomp-devel
BuildRequires:	lzo-devel
BuildRequires:	opencollada-devel
BuildRequires:	openimageio-devel
BuildRequires:	spnav-devel
#BuildRequires:	pkgconfig(audaspace)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(jemalloc)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libopenjpeg1)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenColorIO)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(python3) >= 3.2
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pythonegg(3)(requests)

Requires:		python(abi) >= 3.2
Requires:		pythonegg(3)(requests)
Requires:		pythonegg(3)(numpy)
Requires(post,preun):	GConf2

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%prep
%setup -q

%patch0 -p1 -b .localedir
%ifarch %{ix86}
%patch1 -p0 -b .sse
%endif
%patch2 -p0 -b .static
%patch3 -p1 -b .bool
%patch4 -p0 -b .uninit
%patch5 -p1 -b .sse2
%patch6 -p1 -b .link
%patch7 -p1 -b .jet
%patch8 -p1 -b .manpage

find -name '.svn' -print | xargs rm -rf

%build
export LD=/usr/bin/ld.gold
%ifarch %{ix86}
# build non-sse flavour
%cmake \
	-DCMAKE_SKIP_RPATH=ON \
	-DBUILD_SHARED_LIBS=OFF \
	-DWITH_INSTALL_PORTABLE=OFF \
	-DWITH_GAMEENGINE:BOOL=ON \
	-DWITH_PLAYER:BOOL=ON \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{python3_version} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_IMAGE_OPENJPEG:BOOL=ON \
	-DWITH_OPENCOLLADA:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_CYCLES:BOOL=ON \
	-DWITH_CXX_GUARDEDALLOC:BOOL=OFF \
	-DWITH_MEM_JEMALLOC:BOOL=ON \
	-DWITH_OPENCOLORIO:BOOL=ON \
	-DWITH_SDL:BOOL=ON \
	-DWITH_DOC_MANPAGE:BOOL=ON \
	-DWITH_INPUT_NDOF:BOOL=ON \
	-DWITH_SYSTEM_AUDASPACE:BOOL=OFF \
	-DWITH_SYSTEM_EIGEN3:BOOL=ON \
	-DWITH_SYSTEM_LZO:BOOL=ON \
	-DWITH_SYSTEM_OPENJPEG:BOOL=ON \
	-DSUPPORT_SSE2_BUILD=OFF \
	-DSUPPORT_SSE_BUILD=OFF \
	-DWITH_RAYOPTIMIZATION:BOOL=OFF \
	-DWITH_JACK:BOOL=ON
%make_build
cd ..
mv build non-sse
%endif

#build sse flavour
%cmake \
	-DCMAKE_SKIP_RPATH=ON \
	-DBUILD_SHARED_LIBS=OFF \
	-DWITH_INSTALL_PORTABLE=OFF \
	-DWITH_GAMEENGINE:BOOL=ON \
	-DWITH_PLAYER:BOOL=ON \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{python3_version} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_IMAGE_OPENJPEG:BOOL=ON \
	-DWITH_OPENCOLLADA:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_CYCLES:BOOL=ON \
	-DWITH_CXX_GUARDEDALLOC:BOOL=OFF \
	-DWITH_MEM_JEMALLOC:BOOL=ON \
	-DWITH_OPENCOLORIO:BOOL=ON \
	-DWITH_SDL:BOOL=ON \
	-DWITH_DOC_MANPAGE:BOOL=ON \
	-DWITH_INPUT_NDOF:BOOL=ON \
	-DWITH_SYSTEM_AUDASPACE:BOOL=OFF \
	-DWITH_SYSTEM_EIGEN3:BOOL=ON \
	-DWITH_SYSTEM_LZO:BOOL=ON \
	-DWITH_SYSTEM_OPENJPEG:BOOL=ON \
%ifarch %{ix86}
	-DSUPPORT_SSE2_BUILD=OFF \
%endif
%ifarch %{ix86} x86_64
	-DWITH_RAYOPTIMIZATION:BOOL=ON \
	-DWITH_CYCLES:BOOL=ON \
%else
	-DWITH_RAYOPTIMIZATION:BOOL=OFF \
	-DWITH_CYCLES:BOOL=OFF \
%endif
	-DWITH_JACK:BOOL=ON
%make_build

%install
#install sse flavour
%make_install -C build

%ifarch %{ix86}
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.sse

#install non-sse flavour
rm -fr build
mv non-sse build
%make_install -C build
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

sed -i -e 's,#!/usr/bin/python,#!/usr/bin/python3,' %{buildroot}%{_bindir}/blender-thumbnailer.py %{buildroot}%{_datadir}/%{name}/*/scripts/modules/blend_render_info.py

%find_lang %{name}

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer.py %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

%files -f %{name}.lang
%doc release/text/*
%doc release/datafiles/LICENSE*.ttf.txt
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*.1.*
%{_iconsdir}/hicolor/*/apps/%{name}.*


%changelog
* Tue May 02 2017 akien <akien> 2.78c-4.mga6
+ Revision: 1098269
- Rebuild for ffmpeg 3.3

* Wed Mar 29 2017 neoclust <neoclust> 2.78c-3.mga6
+ Revision: 1095183
- Build on armv5, audaspace is now available

* Wed Mar 08 2017 akien <akien> 2.78c-2.mga6
+ Revision: 1089840
- Rebuild for ffmpeg 3.2.4

* Fri Mar 03 2017 daviddavid <daviddavid> 2.78c-1.mga6
+ Revision: 1088624
- new version: 2.78c

* Fri Feb 10 2017 daviddavid <daviddavid> 2.78b-1.mga6
+ Revision: 1085486
- new version: 2.78b
- rename and rediff link and sse2 patches

* Tue Jan 31 2017 daviddavid <daviddavid> 2.78a-6.mga6
+ Revision: 1084405
- add BR spnav-devel to properly enable NDOF input devices (SpaceNavigator and friends)

* Tue Jan 31 2017 daviddavid <daviddavid> 2.78a-5.mga6
+ Revision: 1084382
- enable buildinfo (BR git)
- add blenderplayer man page
- remove manual installation of icons, the install target is already installing them in the same way

* Tue Jan 31 2017 barjac <barjac> 2.78a-4.mga6
+ Revision: 1084304
- Rebuild for eigen3
- upstream patch to fix build against eigen3-3.3.x

* Wed Dec 28 2016 wally <wally> 2.78a-2.mga6
+ Revision: 1078453
- rebuild for new openimageio

* Fri Oct 28 2016 daviddavid <daviddavid> 2.78a-1.mga6
+ Revision: 1063839
- new version: 2.78a

* Sat Oct 01 2016 daviddavid <daviddavid> 2.78-1.mga6
+ Revision: 1057989
- new version: 2.78
- use system lzo and eigen3
- force to use system openjpeg
- remove merged upstream jack-libname patch
- do not build on ARMv5

* Tue Sep 20 2016 daviddavid <daviddavid> 2.77a-3.mga6
+ Revision: 1054652
- rebuild for new opencollada

* Mon Jul 11 2016 pterjan <pterjan> 2.77a-2.mga6
+ Revision: 1041180
- Maybe fix build on non sse architectures

* Sat Apr 09 2016 daviddavid <daviddavid> 2.77a-1.mga6
+ Revision: 999810
- new version: 2.77a
- requires pythonegg(3)(numpy)

* Tue Mar 22 2016 daviddavid <daviddavid> 2.77-1.mga6
+ Revision: 994065
- new version: 2.77
- rediff link patch

* Wed Jan 06 2016 daviddavid <daviddavid> 2.76b-5.mga6
+ Revision: 920142
- rebuild for new openimageio 1.6.9

* Wed Jan 06 2016 daviddavid <daviddavid> 2.76b-4.mga6
+ Revision: 919983
- enable sdl2 support

* Fri Dec 25 2015 daviddavid <daviddavid> 2.76b-3.mga6
+ Revision: 914606
- rebuild for new boost 1.60.0

* Thu Nov 19 2015 daviddavid <daviddavid> 2.76b-2.mga6
+ Revision: 904141
- rebuild for new jemalloc 4.0.4

* Wed Nov 04 2015 daviddavid <daviddavid> 2.76b-1.mga6
+ Revision: 897838
- new version: 2.76b

* Tue Oct 13 2015 daviddavid <daviddavid> 2.76-1.mga6
+ Revision: 890238
- new version: 2.76
- rename and rediff patch0 (blender-2.76-localedir.patch)
- remove merged upstream patch8
- rebuild for python 3.5
- use new python macros

* Fri Sep 25 2015 daviddavid <daviddavid> 2.75a-6.mga6
+ Revision: 883442
- rebuild for new boost 1.59.0

* Tue Sep 15 2015 daviddavid <daviddavid> 2.75a-5.mga6
+ Revision: 879550
- update doc file list (fix build with new rpm 4.13.0)

  + alexl <alexl>
    - update translations for desktop file

* Wed Aug 26 2015 fwang <fwang> 2.75a-4.mga6
+ Revision: 869494
- rebuild for glew

* Fri Jul 31 2015 fwang <fwang> 2.75a-3.mga6
+ Revision: 859425
- rebuild for new boost

* Tue Jul 28 2015 daviddavid <daviddavid> 2.75a-2.mga6
+ Revision: 858360
- enable again OPENCOLLADA support with the new opencollada package update

* Thu Jul 09 2015 fwang <fwang> 2.75a-1.mga6
+ Revision: 852999
- 2.75a

* Sun Jul 05 2015 daviddavid <daviddavid> 2.75-1.mga6
+ Revision: 850891
- disable OPENCOLLADA support for now (fix broken build)
- enable IMAGE_REDCODE support

  + fwang <fwang>
    - 2.75

* Wed Jun 24 2015 akien <akien> 2.74-2.mga6
+ Revision: 841996
- Rebuild for GLEW 1.12

* Sat Jun 20 2015 daviddavid <daviddavid> 2.74-1.mga6
+ Revision: 835804
- new version: 2.74
- rename and rediff Patch0 and Patch7

* Sun Feb 01 2015 daviddavid <daviddavid> 2.73a-1.mga5
+ Revision: 813064
- new version: 2.73a
- rename and rediff linkage patch
- rename and rediff localedir patch (fix for locale files directory)
- switch BuildRequires to pkgconfig()
- update BuildRequires list
- remove merged upstream patches:
  * (harbour-3.2.0-mga-minilzo-2.8.patch and blender-2.71-parallel.patch)
- remove no longer needed 'Recommends: %%{_lib}jack0'
- reorganise and add more cmake build options

* Fri Nov 14 2014 fwang <fwang> 2.71-11.mga5
+ Revision: 796998
- rebuild for new ffmpeg

* Wed Oct 15 2014 umeabot <umeabot> 2.71-10.mga5
+ Revision: 743728
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.71-9.mga5
+ Revision: 678171
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

  + ovitters <ovitters>
    - add gobject-introspection BR for typelib auto BR

* Mon Sep 08 2014 akien <akien> 2.71-8.mga5
+ Revision: 673636
- Reenable opencolorio support that should now be fixed (mga#13767)

* Sun Sep 07 2014 luigiwalser <luigiwalser> 2.71-7.mga5
+ Revision: 673037
- disable opencolorio BR which causes segfault loading YAML config.ocio
- disable sse in non-sse build
- disable kernel sse2
- disable sse2 in non-sse build on i586
- try again to disable sse2 on i586
- try harder to disable sse2 on i586
- add upstream patch to fix parallel build
- add patch from harbour to fix CVE-2014-4607 in bundled minilzo

  + fwang <fwang>
    - correct patch
    - more patch
    - rediff patch
    - 2.71

* Wed Jun 04 2014 fwang <fwang> 2.70a-3.mga5
+ Revision: 632726
- rebuild for new python3

* Thu May 01 2014 luigiwalser <luigiwalser> 2.70a-2.mga5
+ Revision: 619147
- rebuild for ilmbase

* Sat Apr 12 2014 fwang <fwang> 2.70a-1.mga5
+ Revision: 613576
- 2.70a

* Thu Mar 20 2014 fwang <fwang> 2.70-1.mga5
+ Revision: 606302
- fix linkage patch
- 2.70

* Fri Jan 17 2014 luigiwalser <luigiwalser> 2.69-1.mga5
+ Revision: 566760
+ rebuild (emptylog)

* Wed Nov 06 2013 zezinho <zezinho> 2.69-1.mga4
+ Revision: 549771
- new version 2.6.9

* Tue Oct 22 2013 umeabot <umeabot> 2.68a-5.mga4
+ Revision: 541349
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 fwang <fwang> 2.68a-4.mga4
+ Revision: 495644
- force python3

* Thu Sep 12 2013 fwang <fwang> 2.68a-3.mga4
+ Revision: 477855
- rebuild for new openexr

* Wed Jul 24 2013 sander85 <sander85> 2.68a-2.mga4
+ Revision: 457684
- Rebuild for new glew

* Wed Jul 24 2013 fwang <fwang> 2.68a-1.mga4
+ Revision: 457610
- new version 2.68a
- new version 2.68a
- drop old patch

* Fri Jul 19 2013 fwang <fwang> 2.68-1.mga4
+ Revision: 456227
- new version 2.68

* Mon Jul 15 2013 fwang <fwang> 2.67b-7.mga4
+ Revision: 454653
- rebuild for new openimageio

* Thu Jul 11 2013 fwang <fwang> 2.67b-6.mga4
+ Revision: 452694
- rebuild for new ffmpeg

* Mon Jul 08 2013 fwang <fwang> 2.67b-5.mga4
+ Revision: 451187
- rebuild for new boost

* Wed Jul 03 2013 fwang <fwang> 2.67b-4.mga4
+ Revision: 449845
- try using ld.gold
- rebuild for new openjpeg

* Mon Jun 03 2013 fwang <fwang> 2.67b-2.mga4
+ Revision: 435537
- rebuild for new libpng

* Fri May 31 2013 fwang <fwang> 2.67b-1.mga4
+ Revision: 433529
- new version 2.67b

* Wed May 29 2013 fwang <fwang> 2.67a-2.mga4
+ Revision: 431822
- build with jack dynamic loading

* Sat May 25 2013 fwang <fwang> 2.67a-1.mga4
+ Revision: 427107
- build static lib
- build static lib
- fix localedir
- fix str fmt
- new version 2.67a

* Thu Apr 11 2013 barjac <barjac> 2.65a-5.mga3
+ Revision: 409767
- rebuild for boost-1.53

* Fri Jan 11 2013 umeabot <umeabot> 2.65a-4.mga3
+ Revision: 346914
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 2.65a-3.mga3
+ Revision: 341590
- rebuild for new ffmpeg

* Fri Dec 21 2012 cjw <cjw> 2.65a-2.mga3
+ Revision: 333650
- fix hardcoding of languages file location in patch0 that caused blender to crash at startup (mga #8394)

* Fri Dec 21 2012 fwang <fwang> 2.65a-1.mga3
+ Revision: 333544
- new version 2.65a

* Thu Dec 20 2012 fwang <fwang> 2.65-3.mga3
+ Revision: 332972
- rebuild for new boost

* Wed Dec 12 2012 fwang <fwang> 2.65-2.mga3
+ Revision: 329934
- br fftw3

* Wed Dec 12 2012 fwang <fwang> 2.65-1.mga3
+ Revision: 329929
- move languages file into datadir
- new version 2.65

* Sun Dec 02 2012 fwang <fwang> 2.64a-5.mga3
+ Revision: 325003
- rebuild for new openexr

* Sun Nov 11 2012 fwang <fwang> 2.64a-4.mga3
+ Revision: 316919
- br jack (bug#7952)

* Mon Oct 15 2012 fwang <fwang> 2.64a-3.mga3
+ Revision: 306643
- br opencolorio

* Wed Oct 10 2012 fwang <fwang> 2.64a-2.mga3
+ Revision: 304048
- drop support on sse2 in x86 build

* Wed Oct 10 2012 fwang <fwang> 2.64a-1.mga3
+ Revision: 304041
- new version 2.64a

* Sun Oct 07 2012 fwang <fwang> 2.64-3.mga3
+ Revision: 303270
- rebuild for new openjpeg

* Sun Oct 07 2012 fwang <fwang> 2.64-2.mga3
+ Revision: 303164
- try to build ffmpeg engine
- fix stf fmt
- fix str fmt
- fix str fmt
- fix stf fmt
- drop old tarball
- new version 2.64

* Sat Sep 29 2012 fwang <fwang> 2.63a-7.mga3
+ Revision: 300322
- specify py3ver
- update rpm group
- rebuild for new py3.3

* Tue Aug 21 2012 fwang <fwang> 2.63a-6.mga3
+ Revision: 282896
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 2.63a-5.mga3
+ Revision: 276847
- add upstream patch to build with latest boost
- rebuild for new glew

* Wed May 30 2012 fwang <fwang> 2.63a-4.mga3
+ Revision: 249541
- rebuild for new boost

* Mon May 28 2012 fwang <fwang> 2.63a-3.mga3
+ Revision: 247831
- try do not promote ffmpeg now, as it is too new
- apply patch
- fix build with latest ffmpeg headers
- more static lib build

* Mon May 28 2012 fwang <fwang> 2.63a-2.mga3
+ Revision: 247768
- fix build
- br openimageio for cycle engine

* Fri May 11 2012 fwang <fwang> 2.63a-1.mga2
+ Revision: 235264
- new version 2.63a

* Fri Apr 27 2012 fwang <fwang> 2.63-1.mga2
+ Revision: 233462
- SILEN: build correctly
- new version 2.63

* Thu Apr 12 2012 fwang <fwang> 2.62-2.mga2
+ Revision: 230392
- add fedora patch to build with latest openjpeg
- rebuild for new openjpeg

* Fri Feb 17 2012 fwang <fwang> 2.62-1.mga2
+ Revision: 210042
- br boost
- new version 2.62

* Fri Dec 23 2011 fwang <fwang> 2.61-2.mga2
+ Revision: 186497
- rebuild for new tiff

* Thu Dec 15 2011 fwang <fwang> 2.61-1.mga2
+ Revision: 181678
- new version 2.61

* Sun Nov 20 2011 fwang <fwang> 2.60a-3.mga2
+ Revision: 169769
- hardcode python3 usage

* Tue Oct 25 2011 fwang <fwang> 2.60a-2.mga2
+ Revision: 158008
- requires python3

* Tue Oct 25 2011 fwang <fwang> 2.60a-1.mga2
+ Revision: 157935
- new version 2.60a

* Thu Oct 20 2011 fwang <fwang> 2.60-1.mga2
+ Revision: 156766
- new version 2.60

* Fri Oct 07 2011 fwang <fwang> 2.59-5.mga2
+ Revision: 152638
- rebuild for new openjpeg

* Fri Oct 07 2011 fwang <fwang> 2.59-4.mga2
+ Revision: 152604
- rebuild for new openjpeg

* Mon Oct 03 2011 fwang <fwang> 2.59-3.mga2
+ Revision: 151161
- rebuild for new glew

* Mon Sep 12 2011 fwang <fwang> 2.59-2.mga2
+ Revision: 142630
- rebuild for new libpng
- new version 2.59
- add req for scriptles

* Sat Jul 09 2011 fwang <fwang> 2.58a-1.mga2
+ Revision: 120831
- new version 2.58a

* Tue Jun 28 2011 fwang <fwang> 2.58-1.mga2
+ Revision: 115153
- new version 2.58 (python3.2 based)

* Mon May 30 2011 pterjan <pterjan> 2.49b-10.mga1
+ Revision: 100764
- Rebuild with fixed mkrel

* Sun May 29 2011 tmb <tmb> 2.49b-9.mga1.
+ Revision: 100733
- bump rel for missing packages

  + dmorgan <dmorgan>
    - Revert to blender 2.49b

* Tue May 17 2011 dmorgan <dmorgan> 2.57b-3.mga1
+ Revision: 99512
- New version ( from mandriva )

* Mon May 09 2011 ahmad <ahmad> 2.49b-8.mga1
+ Revision: 96662
- Drop BR esound-devel, phasing out esound from the distro

* Sun Mar 27 2011 blino <blino> 2.49b-7.mga1
+ Revision: 78147
- really fix printf format for SCA_ExpressionController.cpp (from upstream SVN)
- use _real_vendor macro for desktop files naming
- remove old distro name and version checks
- remove unused python24 patch
- remove old version checks, mime types and menus
- imported package blender

